# posturner

Posturner is a cover different language part of speech tagger set, which is a set of tools for natural language processing.
Different language written by a map file. It can be used to tag the parts of speech of a text. You can use it transfrom different language pos tags to universal pos tags.

Such as:
- nimisõna(et) -> NOUN
- tegusõna(et) -> VERB
- noun(en) -> NOUN
- 名词(zh) -> NOUN
- 動詞(ja) -> VERB
- اسم(ur) -> NOUN
....

## Usage

For most occation, you just need set folder, pick your need language map file and build your own application.

We also provide a multi-language.map file. It contains all of the language map files.

